==> esup-canal-intranet-3.10.zip: CIntranet-3.10/db/esup-canal-intranet_mysql.sql <==
# phpMyAdmin SQL Dump
# version 2.5.7-pl1
# http://www.phpmyadmin.net
#
# Serveur: cridev.univ-nancy2.fr
# Gnr le : Lundi 21 Fvrier 2005  10:41
# Version du serveur: 3.23.49
# Version de PHP: 4.3.4
# 
# Base de donnes: `esup_intranet`
# 

# --------------------------------------------------------

#
# Structure de la table `INT_ADMIN`
#

CREATE TABLE `INT_ADMIN` (
  `ID_ENT` varchar(240) NOT NULL default '',
  PRIMARY KEY  (`ID_ENT`)
) TYPE=InnoDB;

#
# Contenu de la table `INT_ADMIN`
#

INSERT INTO `INT_ADMIN` VALUES ('admin');

# --------------------------------------------------------

#
# Structure de la table `INT_DOCUMENT`
#

CREATE TABLE `INT_DOCUMENT` (
  `ID_DOC` int(11) NOT NULL default '0',
  `ID_INT` varchar(20) NOT NULL default '',
  `TYPE_DOC` char(1) NOT NULL default '',
  `ID_FOL` int(11) NOT NULL default '0',
  `NAME_DOC` text NOT NULL,
  `DES_DOC` text NOT NULL,
  `FILE_DOC` text NOT NULL,
  `EXT_DOC` varchar(16) default NULL,
  `URL_DOC` text,
  `AUT_DOC` varchar(240) NOT NULL default '',
  `DATE_DOC` varchar(8) NOT NULL default '',
  `DATEVAL_DOC` varchar(8) NOT NULL default '',
  `ORDER_DOC` int(11) NOT NULL default '0',
  `VALID_DOC` char(1) NOT NULL default '',
  `PENDM_DOC` char(1) NOT NULL default '',
  `PENDD_DOC` char(1) NOT NULL default '',
  `HIDDEN_DOC` char(1) NOT NULL default '',
  `ID_DOCMOD` int(11) NOT NULL default '0',
  PRIMARY KEY  (`ID_DOC`,`ID_INT`)
) TYPE=InnoDB;

# --------------------------------------------------------

#
# Structure de la table `INT_ENTITIES`
#

CREATE TABLE `INT_ENTITIES` (
  `ID_INT` varchar(20) NOT NULL default '',
  `TYPE_ENT` char(1) NOT NULL default '',
  `ID_ENT` varchar(240) NOT NULL default '',
  PRIMARY KEY  (`ID_INT`,`TYPE_ENT`,`ID_ENT`)
) TYPE=InnoDB;

# --------------------------------------------------------

#
# Structure de la table `INT_FOLDER`
#

CREATE TABLE `INT_FOLDER` (
  `ID_FOL` int(11) NOT NULL default '0',
  `ID_INT` varchar(20) NOT NULL default '',
  `NAME_FOL` text NOT NULL,
  `ORDER_FOL` int(11) NOT NULL default '0',
  `PARENT_FOL` int(11) NOT NULL default '0',
  `DATE_FOL` varchar(8) NOT NULL default '',
  PRIMARY KEY  (`ID_FOL`)
) TYPE=InnoDB;

# --------------------------------------------------------

#
# Structure de la table `INT_GRANT`
#

CREATE TABLE `INT_GRANT` (
  `ID_FOL` int(11) NOT NULL default '0',
  `TYPE_GRT` tinyint(4) NOT NULL default '0',
  `TYPE_ENT` char(1) NOT NULL default '',
  `ID_ENT` varchar(240) NOT NULL default '',
  `EXT_GRT` char(1) NOT NULL default '',
  `NOT_GRT` char(1) NOT NULL default '',
  PRIMARY KEY  (`ID_FOL`,`TYPE_GRT`,`TYPE_ENT`,`ID_ENT`)
) TYPE=InnoDB;

# --------------------------------------------------------

#
# Structure de la table `INT_INTRANET`
#

CREATE TABLE `INT_INTRANET` (
  `ID_INT` varchar(20) NOT NULL default '',
  `NAME_INT` text NOT NULL,
  `ORDER_INT` int(11) NOT NULL default '0',
  `RES_INT` varchar(20) NOT NULL default '',
  `FOL_INT` int(11) NOT NULL default '0',
  `ID_DOC` int(11) NOT NULL default '0',
  PRIMARY KEY  (`ID_INT`)
) TYPE=InnoDB;

# --------------------------------------------------------

#
# Structure de la table `INT_KEY`
#

CREATE TABLE `INT_KEY` (
  `NAME_KEY` varchar(16) NOT NULL default '',
  `VALUE_KEY` int(11) NOT NULL default '0',
  PRIMARY KEY  (`NAME_KEY`)
) TYPE=InnoDB;

#
# Contenu de la table `INT_KEY`
#

INSERT INTO `INT_KEY` VALUES ('INT_FOLDER', 1);

# --------------------------------------------------------

#
# Structure de la table `INT_MIME`
#

CREATE TABLE `INT_MIME` (
  `EXT_MIME` varchar(16) NOT NULL default '',
  `TYPE_MIME` text NOT NULL,
  PRIMARY KEY  (`EXT_MIME`)
) TYPE=InnoDB;

#
# Contenu de la table `INT_MIME`
#

INSERT INTO `INT_MIME` VALUES ('.doc', 'application/msword');
INSERT INTO `INT_MIME` VALUES ('.gz', 'application/x-gzip');
INSERT INTO `INT_MIME` VALUES ('.htm', 'text/html');
INSERT INTO `INT_MIME` VALUES ('.html', 'text/html');
INSERT INTO `INT_MIME` VALUES ('.pdf', 'application/pdf');
INSERT INTO `INT_MIME` VALUES ('.ppt', 'application/mspowerpoint');
INSERT INTO `INT_MIME` VALUES ('.rar', 'application/rar');
INSERT INTO `INT_MIME` VALUES ('.tar', 'application/x-tar');
INSERT INTO `INT_MIME` VALUES ('.txt', 'text/plain');
INSERT INTO `INT_MIME` VALUES ('.xls', 'application/msexcel');
INSERT INTO `INT_MIME` VALUES ('.zip', 'application/zip');

==> esup-canal-intranet-3.20.zip: CIntranet-3.20/db/esup-canal-intranet_mysql.sql <==
# phpMyAdmin SQL Dump
# version 2.5.7-pl1
# http://www.phpmyadmin.net
#
# Serveur: cridev.univ-nancy2.fr
# Gnr le : Lundi 21 Fvrier 2005  10:41
# Version du serveur: 3.23.49
# Version de PHP: 4.3.4
# 
# Base de donnes: `esup_intranet`
# 

# --------------------------------------------------------

#
# Structure de la table `INT_ADMIN`
#

CREATE TABLE `INT_ADMIN` (
  `ID_ENT` varchar(240) NOT NULL default '',
  PRIMARY KEY  (`ID_ENT`)
) TYPE=InnoDB;

#
# Contenu de la table `INT_ADMIN`
#

INSERT INTO `INT_ADMIN` VALUES ('admin');

# --------------------------------------------------------

#
# Structure de la table `INT_DOCUMENT`
#

CREATE TABLE `INT_DOCUMENT` (
  `ID_DOC` int(11) NOT NULL default '0',
  `ID_INT` varchar(20) NOT NULL default '',
  `TYPE_DOC` char(1) NOT NULL default '',
  `ID_FOL` int(11) NOT NULL default '0',
  `NAME_DOC` text NOT NULL,
  `DES_DOC` text NOT NULL,
  `FILE_DOC` text NOT NULL,
  `EXT_DOC` varchar(16) default NULL,
  `URL_DOC` text,
  `AUT_DOC` varchar(240) NOT NULL default '',
  `DATE_DOC` varchar(8) NOT NULL default '',
  `DATEVAL_DOC` varchar(8) NOT NULL default '',
  `ORDER_DOC` int(11) NOT NULL default '0',
  `VALID_DOC` char(1) NOT NULL default '',
  `PENDM_DOC` char(1) NOT NULL default '',
  `PENDD_DOC` char(1) NOT NULL default '',
  `HIDDEN_DOC` char(1) NOT NULL default '',
  `ID_DOCMOD` int(11) NOT NULL default '0',
  PRIMARY KEY  (`ID_DOC`,`ID_INT`)
) TYPE=InnoDB;

# --------------------------------------------------------

#
# Structure de la table `INT_ENTITIES`
#

CREATE TABLE `INT_ENTITIES` (
  `ID_INT` varchar(20) NOT NULL default '',
  `TYPE_ENT` char(1) NOT NULL default '',
  `ID_ENT` varchar(240) NOT NULL default '',
  PRIMARY KEY  (`ID_INT`,`TYPE_ENT`,`ID_ENT`)
) TYPE=InnoDB;

# --------------------------------------------------------
ALTER TABLE `INT_FOLDER` ADD `NOT_FOL` VARCHAR(1) DEFAULT '0' NOT NULL;
#
# Structure de la table `INT_FOLDER`
#

CREATE TABLE `INT_FOLDER` (
  `ID_FOL` int(11) NOT NULL default '0',
  `ID_INT` varchar(20) NOT NULL default '',
  `NAME_FOL` text NOT NULL,
  `ORDER_FOL` int(11) NOT NULL default '0',
  `PARENT_FOL` int(11) NOT NULL default '0',
  `DATE_FOL` varchar(8) NOT NULL default '',
  `NOT_FOL` varchar(1) NOT NULL default '0',
  `MAIL_FOL` text NOT NULL default '',
  PRIMARY KEY  (`ID_FOL`)
) TYPE=InnoDB;

# --------------------------------------------------------

#
# Structure de la table `INT_GRANT`
#

CREATE TABLE `INT_GRANT` (
  `ID_FOL` int(11) NOT NULL default '0',
  `TYPE_GRT` tinyint(4) NOT NULL default '0',
  `TYPE_ENT` char(1) NOT NULL default '',
  `ID_ENT` varchar(240) NOT NULL default '',
  `EXT_GRT` char(1) NOT NULL default '',
  `NOT_GRT` char(1) NOT NULL default '',
  PRIMARY KEY  (`ID_FOL`,`TYPE_GRT`,`TYPE_ENT`,`ID_ENT`)
) TYPE=InnoDB;

# --------------------------------------------------------

#
# Structure de la table `INT_INTRANET`
#

CREATE TABLE `INT_INTRANET` (
  `ID_INT` varchar(20) NOT NULL default '',
  `NAME_INT` text NOT NULL,
  `DES_INT` text NOT NULL default '',
  `ORDER_INT` int(11) NOT NULL default '0',
  `RES_INT` varchar(20) NOT NULL default '',
  `FOL_INT` int(11) NOT NULL default '0',
  `ID_DOC` int(11) NOT NULL default '0',
  PRIMARY KEY  (`ID_INT`)
) TYPE=InnoDB;

# --------------------------------------------------------

#
# Structure de la table `INT_KEY`
#

CREATE TABLE `INT_KEY` (
  `NAME_KEY` varchar(16) NOT NULL default '',
  `VALUE_KEY` int(11) NOT NULL default '0',
  PRIMARY KEY  (`NAME_KEY`)
) TYPE=InnoDB;

#
# Contenu de la table `INT_KEY`
#

INSERT INTO `INT_KEY` VALUES ('INT_FOLDER', 1);

# --------------------------------------------------------

#
# Structure de la table `INT_MIME`
#

CREATE TABLE `INT_MIME` (
  `EXT_MIME` varchar(16) NOT NULL default '',
  `TYPE_MIME` text NOT NULL,
  PRIMARY KEY  (`EXT_MIME`)
) TYPE=InnoDB;

#
# Contenu de la table `INT_MIME`
#

INSERT INTO `INT_MIME` VALUES ('.doc', 'application/msword');
INSERT INTO `INT_MIME` VALUES ('.gz', 'application/x-gzip');
INSERT INTO `INT_MIME` VALUES ('.htm', 'text/html');
INSERT INTO `INT_MIME` VALUES ('.html', 'text/html');
INSERT INTO `INT_MIME` VALUES ('.pdf', 'application/pdf');
INSERT INTO `INT_MIME` VALUES ('.ppt', 'application/mspowerpoint');
INSERT INTO `INT_MIME` VALUES ('.rar', 'application/rar');
INSERT INTO `INT_MIME` VALUES ('.tar', 'application/x-tar');
INSERT INTO `INT_MIME` VALUES ('.txt', 'text/plain');
INSERT INTO `INT_MIME` VALUES ('.xls', 'application/msexcel');
INSERT INTO `INT_MIME` VALUES ('.zip', 'application/zip');
